window.Gleam.initSearch([{"doc":"p5js_gleam","title":"p5js_gleam","content":"# p5js_gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/p5js_gleam)](https://hex.pm/packages/p5js_gleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/p5js_gleam/)\n\nA simple game library providing [p5js](https://p5js.org/) bindings for Gleam in a functional style to make basic games and animations. Heavily inspired by the Racket library 2htdp/universe.\n\nThis project is primarily made up of\n\n- A [bun](https://bun.sh/) script that is used to generate bindings for p5js class methods\n  - Script is based on script created for [glare](https://github.com/Enderchief/glare/tree/master/scripts)\n- A wrapper game engine that provides a functional interface to p5js\n\n## Showcase\n\nAn example generated maze\n\n![maze_room](https://github.com/Acepie/p5js_gleam/assets/5996838/e7e21eb0-dad2-486d-99bb-40f4c088e272)\n\nAn example ball spawner\n\n![ball_spawner](https://github.com/Acepie/p5js_gleam/assets/5996838/4869513b-095a-4244-8fc6-6f63738e4c97)\n\n## Using the library\n\nAdd the library to your project by running the following command\n\n```bash\ngleam add p5js_gleam\n```\n\nThen add a call to the `start_sketch` function in your main function.\n\n```gleam\nimport p5js_gleam.{type P5, SketchConfig}\nimport p5js_gleam/bindings as p5\nimport gleam/option\n\nfn setup(p: P5) -&gt; String {\n  p5.create_canvas(p, 800.0, 600.0)\n  &quot;Hello, world!&quot;\n}\n\nfn draw(p: P5, state: String) {\n  p5.background(p, &quot;#ffffff&quot;)\n  p5.fill(p, &quot;#000000&quot;)\n  p5.text(p, state, 400.0, 300.0)\n}\n\npub fn main() {\n  p5.start_sketch(SketchConfig(\n    init: setup,\n    draw: draw,\n    on_tick: option.None,\n    on_key: option.None,\n    on_mouse: option.None,\n  ))\n}\n```\n\nAfterwards you will need to build your project and include it in an html file. The html file must import p5js as a module before the generated javascript file. The easiest way to do this is to load the p5js library from a CDN.\n\n```html\n&lt;!doctype html&gt;\n&lt;html lang=&quot;en&quot;&gt;\n  &lt;head&gt;\n    &lt;meta charset=&quot;UTF-8&quot; /&gt;\n    &lt;meta http-equiv=&quot;X-UA-Compatible&quot; content=&quot;IE=edge&quot; /&gt;\n    &lt;meta name=&quot;viewport&quot; content=&quot;width=device-width, initial-scale=1.0&quot; /&gt;\n    &lt;title&gt;Ball Spawner&lt;/title&gt;\n    &lt;script src=&quot;https://cdn.jsdelivr.net/npm/p5@1.9.2/lib/p5.js&quot;&gt;&lt;/script&gt;\n    &lt;script type=&quot;module&quot;&gt;\n      import { main } from &quot;./ball_spawner.js&quot;;\n      main();\n    &lt;/script&gt;\n  &lt;/head&gt;\n  &lt;body&gt;&lt;/body&gt;\n&lt;/html&gt;\n```\n\nTo see the library in action you can serve one of the examples in the `examples` directory.\n\n## Generating FFI Bindings\n\nTo generate the FFI bindings you will need bun installed. Once you have bun installed run\n\n```bash\nbun run ./scripts/generate_p5.ts\n```\n","url":"index.html"},{"doc":"p5js_gleam","title":"P5","content":"pub type P5\n A reference to the P5js library. Primarily used to access the P5js APIs for drawing.\n\nSynonyms:\np5js_gleam.P5\np5js_gleam P5","url":"p5js_gleam.html#P5"},{"doc":"p5js_gleam","title":"SketchConfig","content":"pub opaque type SketchConfig(model, ignored)\n Configuration to start a sketch. Requires an init function to create the initial model, and a draw function to draw the model. Other handlers can also be provided to update the model based on different user events. Use the `create_sketch` function and the `set_*` helpers to initialize your config.\n\nSynonyms:\np5js_gleam.SketchConfig\np5js_gleam SketchConfig","url":"p5js_gleam.html#SketchConfig"},{"doc":"p5js_gleam","title":"create_sketch","content":"pub fn create_sketch(\n  init init: fn(P5) -&gt; a,\n  draw draw: fn(P5, a) -&gt; b,\n) -&gt; SketchConfig(a, b)\n Creates a minimal sketch configuration.\nSynonyms:\np5js_gleam.create_sketch\np5js_gleam create_sketch","url":"p5js_gleam.html#create_sketch"},{"doc":"p5js_gleam","title":"set_on_key_pressed","content":"pub fn set_on_key_pressed(\n  s: SketchConfig(a, b),\n  on_key_pressed: fn(String, Int, a) -&gt; a,\n) -&gt; SketchConfig(a, b)\n Sets the `on_key_pressed` function to be called.\nSynonyms:\np5js_gleam.set_on_key_pressed\np5js_gleam set_on_key_pressed","url":"p5js_gleam.html#set_on_key_pressed"},{"doc":"p5js_gleam","title":"set_on_key_released","content":"pub fn set_on_key_released(\n  s: SketchConfig(a, b),\n  on_key_released: fn(String, Int, a) -&gt; a,\n) -&gt; SketchConfig(a, b)\n Sets the `on_key_released` function to be called.\nSynonyms:\np5js_gleam.set_on_key_released\np5js_gleam set_on_key_released","url":"p5js_gleam.html#set_on_key_released"},{"doc":"p5js_gleam","title":"set_on_mouse_clicked","content":"pub fn set_on_mouse_clicked(\n  s: SketchConfig(a, b),\n  on_mouse_clicked: fn(Float, Float, a) -&gt; a,\n) -&gt; SketchConfig(a, b)\n Sets the `on_mouse_clicked` function to be called.\nSynonyms:\np5js_gleam.set_on_mouse_clicked\np5js_gleam set_on_mouse_clicked","url":"p5js_gleam.html#set_on_mouse_clicked"},{"doc":"p5js_gleam","title":"set_on_mouse_moved","content":"pub fn set_on_mouse_moved(\n  s: SketchConfig(a, b),\n  on_mouse_moved: fn(Float, Float, a) -&gt; a,\n) -&gt; SketchConfig(a, b)\n Sets the `on_mouse_moved` function to be called.\nSynonyms:\np5js_gleam.set_on_mouse_moved\np5js_gleam set_on_mouse_moved","url":"p5js_gleam.html#set_on_mouse_moved"},{"doc":"p5js_gleam","title":"set_on_tick","content":"pub fn set_on_tick(\n  s: SketchConfig(a, b),\n  on_tick: fn(a) -&gt; a,\n) -&gt; SketchConfig(a, b)\n Sets the `on_tick` function to be called.\nSynonyms:\np5js_gleam.set_on_tick\np5js_gleam set_on_tick","url":"p5js_gleam.html#set_on_tick"},{"doc":"p5js_gleam","title":"p5js_gleam","content":"","url":"p5js_gleam.html"},{"doc":"p5js_gleam/bindings","title":"background","content":"pub fn background(p: P5, color: String) -&gt; P5\n A binding to the p5.js [`background`](https://p5js.org/reference/#/p5/background) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.background\np5js_gleam/bindings background","url":"p5js_gleam/bindings.html#background"},{"doc":"p5js_gleam/bindings","title":"circle","content":"pub fn circle(\n  p: P5,\n  x_center: Float,\n  y_center: Float,\n  radius: Float,\n) -&gt; P5\n A binding to the p5.js [`circle`](https://p5js.org/reference/#/p5/circle) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.circle\np5js_gleam/bindings circle","url":"p5js_gleam/bindings.html#circle"},{"doc":"p5js_gleam/bindings","title":"create_canvas","content":"pub fn create_canvas(p: P5, width: Float, height: Float) -&gt; P5\n A binding to the p5.js [`createCanvas`](https://p5js.org/reference/#/p5/createCanvas) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.create_canvas\np5js_gleam/bindings create_canvas","url":"p5js_gleam/bindings.html#create_canvas"},{"doc":"p5js_gleam/bindings","title":"ellipse","content":"pub fn ellipse(\n  p: P5,\n  x_center: Float,\n  y_center: Float,\n  width: Float,\n  height: Float,\n) -&gt; P5\n A binding to the p5.js [`ellipse`](https://p5js.org/reference/#/p5/ellipse) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.ellipse\np5js_gleam/bindings ellipse","url":"p5js_gleam/bindings.html#ellipse"},{"doc":"p5js_gleam/bindings","title":"fill","content":"pub fn fill(p: P5, color_hex: String) -&gt; P5\n A binding to the p5.js [`fill`](https://p5js.org/reference/#/p5/fill) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.fill\np5js_gleam/bindings fill","url":"p5js_gleam/bindings.html#fill"},{"doc":"p5js_gleam/bindings","title":"line","content":"pub fn line(\n  p: P5,\n  point1_x: Float,\n  point1_y: Float,\n  point2_x: Float,\n  point2_y: Float,\n) -&gt; P5\n A binding to the p5.js [`line`](https://p5js.org/reference/#/p5/line) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.line\np5js_gleam/bindings line","url":"p5js_gleam/bindings.html#line"},{"doc":"p5js_gleam/bindings","title":"no_stroke","content":"pub fn no_stroke(p: P5) -&gt; P5\n A binding to the p5.js [`noStroke`](https://p5js.org/reference/#/p5/noStroke) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.no_stroke\np5js_gleam/bindings no_stroke","url":"p5js_gleam/bindings.html#no_stroke"},{"doc":"p5js_gleam/bindings","title":"quad","content":"pub fn quad(\n  p: P5,\n  p1_x: Float,\n  p1_y: Float,\n  p2_x: Float,\n  p2_y: Float,\n  p3_x: Float,\n  p3_y: Float,\n  p4_x: Float,\n  p4_y: Float,\n) -&gt; P5\n A binding to the p5.js [`quad`](https://p5js.org/reference/#/p5/quad) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.quad\np5js_gleam/bindings quad","url":"p5js_gleam/bindings.html#quad"},{"doc":"p5js_gleam/bindings","title":"rect","content":"pub fn rect(\n  p: P5,\n  top_left_x: Float,\n  top_left_y: Float,\n  width: Float,\n  height: Float,\n) -&gt; P5\n A binding to the p5.js [`rect`](https://p5js.org/reference/#/p5/rect) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.rect\np5js_gleam/bindings rect","url":"p5js_gleam/bindings.html#rect"},{"doc":"p5js_gleam/bindings","title":"square","content":"pub fn square(\n  p: P5,\n  top_left_x: Float,\n  top_left_y: Float,\n  side_length: Float,\n) -&gt; P5\n A binding to the p5.js [`square`](https://p5js.org/reference/#/p5/square) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.square\np5js_gleam/bindings square","url":"p5js_gleam/bindings.html#square"},{"doc":"p5js_gleam/bindings","title":"start_sketch","content":"pub fn start_sketch(config: SketchConfig(a, b)) -&gt; Nil\n Starts a p5.js sketch with the given configuration.\nSynonyms:\np5js_gleam/bindings.start_sketch\np5js_gleam/bindings start_sketch","url":"p5js_gleam/bindings.html#start_sketch"},{"doc":"p5js_gleam/bindings","title":"stroke","content":"pub fn stroke(p: P5, color_hex: String) -&gt; P5\n A binding to the p5.js [`stroke`](https://p5js.org/reference/#/p5/stroke) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.stroke\np5js_gleam/bindings stroke","url":"p5js_gleam/bindings.html#stroke"},{"doc":"p5js_gleam/bindings","title":"stroke_weight","content":"pub fn stroke_weight(p: P5, weight: Int) -&gt; P5\n A binding to the p5.js [`strokeWeight`](https://p5js.org/reference/#/p5/strokeWeight) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.stroke_weight\np5js_gleam/bindings stroke_weight","url":"p5js_gleam/bindings.html#stroke_weight"},{"doc":"p5js_gleam/bindings","title":"text","content":"pub fn text(\n  p: P5,\n  text: String,\n  bottom_corner_x: Float,\n  bottom_corner_y: Float,\n) -&gt; P5\n A binding to the p5.js [`text`](https://p5js.org/reference/#/p5/text) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.text\np5js_gleam/bindings text","url":"p5js_gleam/bindings.html#text"},{"doc":"p5js_gleam/bindings","title":"text_size","content":"pub fn text_size(p: P5, size: Int) -&gt; P5\n A binding to the p5.js [`textSize`](https://p5js.org/reference/#/p5/textSize) function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.text_size\np5js_gleam/bindings text_size","url":"p5js_gleam/bindings.html#text_size"},{"doc":"p5js_gleam/bindings","title":"p5js_gleam/bindings","content":"","url":"p5js_gleam/bindings.html"}]);